@@ -16,8 +16,11 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {}[@var{a} = logsig (@var{n})
-## A neural feed-forward network will be trained with @code{trainlm}
+## @deftypefn {Function File} {}@var{a} = logsig (@var{n})
+## @code{logsig} is a non-linear transfer function used to train
+## neural networks.
+## This function can be used in newff(...) to create a new feed forward
+## multi-layer neural network.
 ##
 ## @end deftypefn
 
